==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/RemoteActivityCategoryServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:RemoteActivityCategoryBackendServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.remoteservice.impl
 * Date:2016年6月7日上午8:55:59
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.remoteservice.impl;

import cn.com.duiba.activity.center.api.dto.ActivityCategoryDto;
import cn.com.duiba.activity.center.api.dto.CategoryActivityDto;
import cn.com.duiba.activity.center.api.remoteservice.RemoteActivityCategoryService;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryRelationEntity;
import cn.com.duiba.activity.center.biz.entity.activity.OperatingActivityEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryRelationService;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryService;
import cn.com.duiba.activity.center.biz.service.activity.OperatingActivityService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * ClassName:RemoteActivityCategoryBackendServiceImpl <br/>
 * Date:	 2016年6月7日 上午8:55:59 <br/>
 * @author   xuhengfei
 * @version  
 * @since	JDK 1.6
 * @see 	 
 */
@Service("remoteActivityCategoryService")
public class RemoteActivityCategoryServiceImpl implements RemoteActivityCategoryService{
	
	private static final Logger log=LoggerFactory.getLogger(RemoteActivityCategoryServiceImpl.class);
	@Autowired
	private ActivityCategoryService activityCategoryService;
	@Autowired
	private ActivityCategoryRelationService activityCategoryRelationService;
	@Autowired
	private OperatingActivityService operatingActivityService;
	
	@Override
	public DubboResult<ActivityCategoryDto> findById(long id) {
		try{
			ActivityCategoryEntity endtity=activityCategoryService.findById(id);
			ActivityCategoryDto dto=new ActivityCategoryDto();
			dto.setId(endtity.getId());
			dto.setName(endtity.getName());
			dto.setEnable(endtity.getEnable());
			dto.setContent(endtity.getContent());
			return DubboResult.successResult(dto);
		}catch(Exception e){
			log.error("findAll",e);
			return DubboResult.failResult(e.getMessage());
		}
	}
	
	@Override
	public DubboResult<List<CategoryActivityDto>> findAllActivitiesByAppCategory(long appId, long categoryId,int start,int pageSize) {
		try {
			// find all by appId,categoryId
			List<ActivityCategoryRelationEntity> acrs = this.activityCategoryRelationService.findByAppCategory(appId,categoryId,start,pageSize);
			List<CategoryActivityDto> dtos = new ArrayList<CategoryActivityDto>();

			if (acrs != null && acrs.size() > 0) {
				for (ActivityCategoryRelationEntity acr : acrs) {
					
					CategoryActivityDto dto = new CategoryActivityDto();
					OperatingActivityEntity enty=operatingActivityService.findById(acr.getOperatingActivityId());
					dto.setId(acr.getId());
					dto.setOperatingId(acr.getOperatingActivityId());
					dto.setPayload(acr.getPayload());
					dto.setAppId(appId);
					dto.setCategoryId(categoryId);
					dto.setTitle(enty.getTitle());
					dto.setThumb(enty.getSmallImage());
					dto.setBanner(enty.getImage());
					if(enty.getCustomCredits() !=null && enty.getCustomCredits() >0L){
						dto.setCredits(enty.getCustomCredits());
					}else{
						dto.setCredits(enty.getCredits());
					}
					dto.setAppItemId(enty.getAppItemId());
					dtos.add(dto);
				}
			}
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			log.error("findAllActivitiesByAppCategory error,appId="+appId+",categoryId="+categoryId , e);
			return DubboResult.failResult(e.getMessage());
		}
	}
}

==> activity-center-biz-1.2.8.3-20161025.011418-1-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/RemoteActivityCategoryServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:RemoteActivityCategoryBackendServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.remoteservice.impl
 * Date:2016年6月7日上午8:55:59
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.remoteservice.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.ActivityCategoryDto;
import cn.com.duiba.activity.center.api.dto.CategoryActivityDto;
import cn.com.duiba.activity.center.api.remoteservice.RemoteActivityCategoryService;
import cn.com.duiba.activity.center.biz.bo.activity.CategoryActivityBo;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryRelationEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryRelationService;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryService;
import cn.com.duiba.activity.center.biz.service.activity.OperatingActivityService;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteActivityCategoryBackendServiceImpl <br/>
 * Date:	 2016年6月7日 上午8:55:59 <br/>
 * @author   xuhengfei
 * @version  
 * @since	JDK 1.6
 * @see 	 
 */
@Service("remoteActivityCategoryService")
public class RemoteActivityCategoryServiceImpl implements RemoteActivityCategoryService{
	
	private static final Logger log=LoggerFactory.getLogger(RemoteActivityCategoryServiceImpl.class);
	@Autowired
	private ActivityCategoryService activityCategoryService;
	@Autowired
	private ActivityCategoryRelationService activityCategoryRelationService;
	@Autowired
	private OperatingActivityService operatingActivityService;
	@Autowired
	private CategoryActivityBo categoryActivityBo;
	
	@Override
	public DubboResult<ActivityCategoryDto> findById(long id) {
		try{
			ActivityCategoryEntity endtity=activityCategoryService.findById(id);
			ActivityCategoryDto dto = null;
			if(endtity!=null) {
				dto = new ActivityCategoryDto();
				dto.setId(endtity.getId());
				dto.setName(endtity.getName());
				dto.setEnable(endtity.getEnable());
				dto.setContent(endtity.getContent());
			}
			return DubboResult.successResult(dto);
		}catch(Exception e){
			log.error("findAll",e);
			return DubboResult.failResult(e.getMessage());
		}
	}
	
	@Override
	public DubboResult<List<CategoryActivityDto>> findAllActivitiesByAppCategory(long appId, long categoryId,int start,int pageSize) {
		try {
			// find all by appId,categoryId
			List<ActivityCategoryRelationEntity> acrs = this.activityCategoryRelationService.findByAppCategory(appId,categoryId,start,pageSize);
			List<CategoryActivityDto> dtos = new ArrayList<CategoryActivityDto>();

			if (acrs != null && acrs.size() > 0) {
				for (ActivityCategoryRelationEntity acr : acrs) {
					
					CategoryActivityDto dto = new CategoryActivityDto();
					dto.setId(acr.getId());
					dto.setOperatingId(acr.getOperatingActivityId());
					dto.setPayload(acr.getPayload());
					dto.setAppId(appId);
					dto.setCategoryId(categoryId);
					dtos.add(dto);
				}
			}
			return DubboResult.successResult(dtos);
		} catch (Exception e) {
			log.error("findAllActivitiesByAppCategory error,appId="+appId+",categoryId="+categoryId , e);
			return DubboResult.failResult(e.getMessage());
		}
	}

    @Override
    public DubboResult<List<CategoryActivityDto>> findAllActivitiesByAppCategoryNew(long appId, long categoryId,
                                                                                    long consumerId, String ip,
                                                                                    String os, String clickUlr,
                                                                                    int start, int pageSize) {
        
        try{
            List<CategoryActivityDto> dtos = this.categoryActivityBo.findAllActivitiesByAppCategory(appId, categoryId, consumerId, ip, os, clickUlr, start, pageSize);
            
            return DubboResult.successResult(dtos);
        } catch (Exception e){
            log.error("findAllActivitiesByAppCategoryNew error,appId="+appId+",categoryId="+categoryId , e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> isCategoryEnable(Long appId, Long categoryId) {
        try {
            Boolean enable = categoryActivityBo.isCategoryEnable(appId, categoryId);
            return DubboResult.successResult(enable);
        } catch (Exception e) {
            log.error("invoke isCategoryEnable failed,appId="+appId+",categoryId="+categoryId , e);
            return DubboResult.failResult(e.getMessage());
        }
    }
}
